searchData={"items":[{"type":"module","title":"Sanity","doc":"Client library for Sanity CMS. See the [README](readme.html) for examples.","ref":"Sanity.html"},{"type":"function","title":"Sanity.doc/1","doc":"Generates a request for the [Doc endpoint](https://www.sanity.io/docs/http-doc).\n\nThe Sanity docs suggest using this endpoint sparingly because it is \"less scalable/performant\"\nthan using `query/3`.","ref":"Sanity.html#doc/1"},{"type":"function","title":"Sanity.list_references/1","doc":"Returns a list of document IDs referenced by a document or list of documents.","ref":"Sanity.html#list_references/1"},{"type":"function","title":"Examples - Sanity.list_references/1","doc":"iex> Sanity.list_references(%{_ref: \"abc\", _type: \"reference\"})\n    [\"abc\"]\n\n    iex> Sanity.list_references([%{\"_ref\" => \"one\", \"_type\" => \"reference\"}, %{_ref: \"two\"}, %{\"items\" => [%{\"_ref\" => \"three\"}]}])\n    [\"one\", \"two\", \"three\"]\n\n    iex> Sanity.list_references([%{_ref: \"abc\", _type: \"reference\"}])\n    [\"abc\"]\n\n    iex> Sanity.list_references([%{a: %{_ref: \"abc\", _type: \"reference\"}, b: 1}])\n    [\"abc\"]","ref":"Sanity.html#list_references/1-examples"},{"type":"function","title":"Sanity.mutate/2","doc":"Generates a request for the [Mutate](https://www.sanity.io/docs/http-mutations) endpoint.","ref":"Sanity.html#mutate/2"},{"type":"function","title":"Examples - Sanity.mutate/2","doc":"Sanity.mutate(\n      [\n        %{\n          create: %{\n            _type: \"product\",\n            title: \"Test product\"\n          }\n        }\n      ],\n      return_ids: true\n    )\n    |> Sanity.request(config)","ref":"Sanity.html#mutate/2-examples"},{"type":"function","title":"Sanity.query/3","doc":"Generates a request to the [Query](https://www.sanity.io/docs/http-query) endpoint. Requests to\nthis endpoint may be authenticated or unauthenticated. Unauthenticated requests to a dataset\nwith private visibility will succeed but will not return any documents.\n\n[Perspectives](https://www.sanity.io/docs/perspectives) can be used by passing the `\"perspective\"`\nquery param like, `Sanity.query(\"*\", %{}, perspective: \"previewDrafts\")`. This function does not\nset a perspective by default, which is equivalent to a perspective of `\"raw\"`.","ref":"Sanity.html#query/3"},{"type":"function","title":"Sanity.replace_references/2","doc":"Replaces Sanity references. The input can be a single document or list of documents. References\ncan be deeply nested within the documents. Documents can have either atom or string keys.","ref":"Sanity.html#replace_references/2"},{"type":"function","title":"Examples - Sanity.replace_references/2","doc":"iex> Sanity.replace_references(%{_ref: \"abc\", _type: \"reference\"}, fn \"abc\" -> %{_id: \"abc\"} end)\n    %{_id: \"abc\"}\n\n    iex> Sanity.replace_references(%{\"_ref\" => \"abc\", \"_type\" => \"reference\"}, fn \"abc\" -> %{\"_id\" => \"abc\"} end)\n    %{\"_id\" => \"abc\"}\n\n    iex> Sanity.replace_references(%{_ref: \"abc\"}, fn \"abc\" -> %{_id: \"abc\"} end)\n    %{_id: \"abc\"}\n\n    iex> Sanity.replace_references(%{\"_ref\" => \"abc\"}, fn \"abc\" -> %{\"_id\" => \"abc\"} end)\n    %{\"_id\" => \"abc\"}\n\n    iex> Sanity.replace_references([%{_ref: \"abc\", _type: \"reference\"}], fn _ -> %{_id: \"abc\"} end)\n    [%{_id: \"abc\"}]\n\n    iex> Sanity.replace_references([%{a: %{_ref: \"abc\", _type: \"reference\"}, b: 1}], fn _ -> %{_id: \"abc\"} end)\n    [%{a: %{_id: \"abc\"}, b: 1}]","ref":"Sanity.html#replace_references/2-examples"},{"type":"function","title":"Sanity.request/2","doc":"Submits a request to the Sanity API. Returns `{:ok, response}` upon success or `{:error,\nresponse}` if a non-exceptional (4xx) error occurs. A `Sanity.Error` will be raised if an\nexceptional error such as a 5xx response code, a network timeout, or a response containing\nnon-JSON content occurs.","ref":"Sanity.html#request/2"},{"type":"function","title":"Options - Sanity.request/2","doc":"* `:api_version` (`t:String.t/0`) - The default value is `\"v2021-10-21\"`.\n\n* `:cdn` (`t:boolean/0`) - Should the CDN be used? See the [Sanity docs](https://www.sanity.io/docs/api-cdn) for details. The default value is `false`.\n\n* `:dataset` (`t:String.t/0`) - Required. Sanity dataset.\n\n* `:http_options` (`t:keyword/0`) - Options to be passed to `Req.request/1`. The default value is `[receive_timeout: 30000]`.\n\n* `:project_id` (`t:String.t/0`) - Required. Sanity project ID.\n\n* `:token` (`t:String.t/0`) - Sanity auth token.","ref":"Sanity.html#request/2-options"},{"type":"function","title":"Sanity.request!/2","doc":"Like `request/2`, but raises a `Sanity.Error` instead of returning and error tuple.\n\nSee `request/2` for supported options.","ref":"Sanity.html#request!/2"},{"type":"function","title":"Sanity.result!/1","doc":"Returns the result from a `Sanity.Response` struct.","ref":"Sanity.html#result!/1"},{"type":"function","title":"Examples - Sanity.result!/1","doc":"iex> Sanity.result!(%Sanity.Response{body: %{\"result\" => []}})\n    []\n\n    iex> Sanity.result!(%Sanity.Response{body: %{}, status: 200})\n    ** (Sanity.Error) %Sanity.Response{body: %{}, headers: %{}, status: 200}","ref":"Sanity.html#result!/1-examples"},{"type":"function","title":"Sanity.stream/1","doc":"Returns a lazy `Stream` of results for the given query. The implementation is efficient and\nsuitable for iterating over very large datasets. It is based on the [Paginating with\nGROQ](https://www.sanity.io/docs/paginating-with-groq) article from the Sanity docs.\n\nFailed attempts to fetch a batch will be retried by default. If the max attempts are exceeded\nthen an exception will be raised as descrbied in `request!/2`.\n\nThe current implementation always sorts by ascending `_id`. Support for sorting by other fields\nmay be supported in the future.","ref":"Sanity.html#stream/1"},{"type":"function","title":"Options - Sanity.stream/1","doc":"* `:batch_size` (`t:pos_integer/0`) - Number of results to fetch per request. The Sanity docs say: \"In the general case, we recommend a batch size of no more than 5,000. If your documents are very large, a smaller batch size is better.\" The default value is `1000`.\n\n* `:perspective` (`t:String.t/0`) - Perspective to use. Common values are `\"published\"`, `\"previewDrafts\"`, and `\"raw\"`. See the [docs](https://www.sanity.io/docs/perspectives) for details. The default value is `\"published\"`.\n\n* `:projection` (`t:String.t/0`) - GROQ projection. Must include the `_id` field. The default value is `\"{ ... }\"`.\n\n* `:query` (`t:String.t/0`) - Query string, like `_type == \"page\"`. By default, all documents will be selected.\n\n* `:request_opts` (`t:keyword/0`) - Required. Options to be passed to `request/2`.\n\n* `:variables` - Map of variables to be used with `query`. The default value is `%{}`.","ref":"Sanity.html#stream/1-options"},{"type":"function","title":"Sanity.upload_asset/3","doc":"Generates a request for the [asset endpoint](https://www.sanity.io/docs/http-api-assets). The\n`body` argument can be a binary or iolist to upload content from memory. Or it can be an\n`Enumerable`, such as a value returned by `File.stream!/2`, for streaming uploads.","ref":"Sanity.html#upload_asset/3"},{"type":"function","title":"Options - Sanity.upload_asset/3","doc":"* `:asset_type` - Either `:image` or `:file`. The default value is `:image`.\n\n* `:content_type` (`t:String.t/0`) - Optional `content-type` header. It appears that Sanity is able to infer image types.","ref":"Sanity.html#upload_asset/3-options"},{"type":"function","title":"Query params - Sanity.upload_asset/3","doc":"Sanity doesn't document the query params very well at this time, but the [Sanity Javascript\nclient](https://github.com/sanity-io/sanity/blob/next/packages/%40sanity/client/src/assets/assetsClient.js)\nlists several possible query params:\n\n  * `label` - Label\n  * `title` - Title\n  * `description` - Description\n  * `filename` - Original filename\n  * `meta` - ???\n  * `creditLine` - The credit to person(s) and/or organization(s) required by the supplier of\n    the image to be used when published","ref":"Sanity.html#upload_asset/3-query-params"},{"type":"behaviour","title":"Sanity.Behaviour","doc":"Behaviour implemented by the `Sanity` module. This behaviour includes all functions that make\nrequests to the Sanity API. Pure functions from the `Sanity` module are not included. This\nbehaviour is useful for creating mocks using the `Mox` library.","ref":"Sanity.Behaviour.html"},{"type":"callback","title":"Sanity.Behaviour.request/2","doc":"","ref":"Sanity.Behaviour.html#c:request/2"},{"type":"callback","title":"Sanity.Behaviour.request!/2","doc":"","ref":"Sanity.Behaviour.html#c:request!/2"},{"type":"callback","title":"Sanity.Behaviour.stream/1","doc":"","ref":"Sanity.Behaviour.html#c:stream/1"},{"type":"module","title":"Sanity.Request","doc":"","ref":"Sanity.Request.html"},{"type":"type","title":"Sanity.Request.t/0","doc":"","ref":"Sanity.Request.html#t:t/0"},{"type":"module","title":"Sanity.Response","doc":"","ref":"Sanity.Response.html"},{"type":"type","title":"Sanity.Response.t/0","doc":"","ref":"Sanity.Response.html#t:t/0"},{"type":"exception","title":"Sanity.Error","doc":"Error that may occur while making a request to the Sanity API. The `source` field will be one of\nthe following:\n\n  * `%Req.Response{}` - If response with an unsupported HTTP status (like 5xx) is received.\n  * `%Mint.TransportError{}` - If a network error such as a timeout occurred. In `req` 0.5 this will change to `%Req.TransportError{}`.\n  * `%Sanity.Response{}` - If a 4xx response is received during a call to `Sanity.request!/2`.","ref":"Sanity.Error.html"},{"type":"extras","title":"Sanity","doc":"# Sanity\n\n[![Package](https://img.shields.io/hexpm/v/sanity.svg)](https://hex.pm/packages/sanity) [![Documentation](http://img.shields.io/badge/hex.pm-docs-green.svg?style=flat)](https://hexdocs.pm/sanity) ![CI](https://github.com/balexand/sanity/actions/workflows/elixir.yml/badge.svg)\n\nA client library for the [Sanity CMS API](https://www.sanity.io/docs/http-api).","ref":"readme.html"},{"type":"extras","title":"Installation - Sanity","doc":"The package can be installed by adding `sanity` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:sanity, \"~> 2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Examples - Sanity","doc":"```elixir\nrequest_opts = [project_id: \"abc\", dataset: \"production\", token: \"secret\"]\n```\n\nRequest all published pages using [`Sanity.query/3`](https://hexdocs.pm/sanity/Sanity.html#query/3):\n\n```elixir\nSanity.query(~S'*[_type == \"page\"]', %{}, perspective: \"published\")\n|> Sanity.request!(request_opts)\n```\n\nMake the same request with [`Sanity.stream/1`](https://hexdocs.pm/sanity/Sanity.html#stream/1):\n\n```elixir\nSanity.stream(query: ~S'_type == \"page\"', request_opts: request_opts)\n|> Enum.to_list()\n```","ref":"readme.html#examples"},{"type":"extras","title":"Related Projects - Sanity","doc":"* [`cms`](https://github.com/balexand/cms) - An experimental library for syncing content from any headless CMS to ETS tables.\n* [`sanity_components`](https://github.com/balexand/sanity_components) - Phoenix components for rendering [images](https://www.sanity.io/docs/presenting-images) and [portable text](https://www.sanity.io/docs/presenting-block-text).\n* [`sanity_sync`](https://github.com/balexand/sanity_sync) - For syncing content from Sanity CMS to Ecto.","ref":"readme.html#related-projects"},{"type":"extras","title":"Supported endpoints - Sanity","doc":"- [x] Assets\n- [x] Doc\n- [ ] Export\n- [ ] History\n- [ ] ~Listen~ (see https://github.com/balexand/sanity/pull/74)\n- [x] Mutate\n- [ ] Projects\n- [x] Query","ref":"readme.html#supported-endpoints"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}